(function (global, factory) {
  typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('polythene-core'), require('polythene-theme')) :
  typeof define === 'function' && define.amd ? define(['exports', 'polythene-core', 'polythene-theme'], factory) :
  (factory((global.polythene = {}),global['polythene-core'],global['polythene-theme']));
}(this, (function (exports,polytheneCore,polytheneTheme) { 'use strict';

  var classes = {
    component: "pe-list-tile",

    // elements
    content: "pe-list-tile__content",
    highSubtitle: "pe-list-tile__high-subtitle",
    primary: "pe-list-tile__primary",
    secondary: "pe-list-tile__secondary",
    subtitle: "pe-list-tile__subtitle",
    title: "pe-list-tile__title",
    contentFront: "pe-list-tile__content-front",

    // states
    compact: "pe-list-tile--compact",
    compactFront: "pe-list-tile--compact-front",
    disabled: "pe-list-tile--disabled",
    hasFront: "pe-list-tile--front",
    hasHighSubtitle: "pe-list-tile--high-subtitle",
    hasSubtitle: "pe-list-tile--subtitle",
    header: "pe-list-tile--header",
    hoverable: "pe-list-tile--hoverable",
    selectable: "pe-list-tile--selectable",
    selected: "pe-list-tile--selected",
    highlight: "pe-list-tile--highlight",
    sticky: "pe-list-tile--sticky",
    navigation: "pe-list-tile--navigation"
  };

  var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

  function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

  var getElement = function getElement() {
    return "div";
  }; // because primary or secondary content can be an "a", the container is always defined as "div", and option `element` is passed to primary content

  var primaryContent = function primaryContent(h, k, requiresKeys, attrs, children) {
    var url = attrs.keyboardControl ? null : attrs.url;
    var element = attrs.element ? attrs.element : url ? "a" : "div";
    var contentFrontClass = [classes.content, classes.contentFront, attrs.compactFront ? classes.compactFront : null].join(" ");
    var frontComp = attrs.front ? h("div", _extends({}, requiresKeys ? { key: "front" } : null, { className: contentFrontClass }), attrs.front) : attrs.indent ? h("div", _extends({}, requiresKeys ? { key: "front" } : null, { className: contentFrontClass })) : null;
    var hasTabIndex = !attrs.header && attrs.url;
    var props = _extends({}, polytheneCore.filterSupportedAttributes(attrs), attrs.events, {
      className: classes.primary,
      style: null
    }, hasTabIndex && _defineProperty({}, k.tabindex, attrs[k.tabindex] || 0), url);
    var content = attrs.content ? attrs.content : [frontComp, h("div", {
      className: classes.content,
      style: attrs.style
    }, [attrs.content ? _extends({}, requiresKeys ? { key: "content" } : null, attrs.content) : children, attrs.title && !attrs.content ? h("div", _extends({}, requiresKeys ? { key: "title" } : null, { className: classes.title }), attrs.title) : null, attrs.subtitle ? h("div", _extends({}, requiresKeys ? { key: "subtitle" } : null, { className: classes.subtitle }), attrs.subtitle) : null, attrs.highSubtitle ? h("div", _extends({}, requiresKeys ? { key: "highSubtitle" } : null, { className: classes.subtitle + " " + classes.highSubtitle }), attrs.highSubtitle) : null, attrs.subContent ? h("div", _extends({}, requiresKeys ? { key: "subContent" } : null, { className: classes.subContent }), attrs.subContent) : null])];
    return h(element, props, content);
  };

  var secondaryContent = function secondaryContent(h, k, requiresKeys, Icon) {
    var attrs = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : {};

    var url = attrs.keyboardControl ? null : attrs.url;
    var element = attrs.element ? attrs.element : url ? "a" : "div";
    var hasTabIndex = attrs.url;
    return h(element, _extends({}, url, {
      className: classes.secondary
    }, requiresKeys ? { key: "secondary" } : null, polytheneCore.filterSupportedAttributes(attrs), hasTabIndex && _defineProperty({}, k.tabindex, attrs[k.tabindex] || 0)), h("div", { className: classes.content }, [attrs.icon ? h(Icon, attrs.icon) : null, attrs.content ? attrs.content : null]));
  };

  var createProps = function createProps(vnode, _ref3) {
    var k = _ref3.keys;

    var attrs = vnode.attrs;
    var hasTabIndex = !attrs.header && !attrs.url && !(attrs.secondary && attrs.secondary.url);
    var heightClass = attrs.subtitle ? classes.hasSubtitle : attrs.highSubtitle ? classes.hasHighSubtitle : attrs.front || attrs.indent ? classes.hasFront : null;
    return _extends({}, polytheneCore.filterSupportedAttributes(attrs, { remove: ["tabindex", "tabIndex"] }), // tabindex is set elsewhere
    {
      className: [classes.component, attrs.selected ? classes.selected : null, attrs.disabled ? classes.disabled : null, attrs.sticky ? classes.sticky : null, attrs.compact ? classes.compact : null, attrs.hoverable ? classes.hoverable : null, attrs.selectable ? classes.selectable : null, attrs.highlight ? classes.highlight : null, attrs.header ? classes.header : null, attrs.navigation ? classes.navigation : null, attrs.tone === "dark" ? "pe-dark-tone" : null, attrs.tone === "light" ? "pe-light-tone" : null, heightClass, attrs.className || attrs[k.class]].join(" ")
    }, hasTabIndex && _defineProperty({}, k.tabindex, attrs[k.tabindex] || 0)
    // events and url are attached to primary content to not interfere with controls
    );
  };

  var createContent = function createContent(vnode, _ref5) {
    var h = _ref5.renderer,
        requiresKeys = _ref5.requiresKeys,
        k = _ref5.keys,
        Ripple = _ref5.Ripple,
        Icon = _ref5.Icon;

    var attrs = vnode.attrs;
    var primaryAttrs = _extends({}, requiresKeys ? { key: "primary" } : null, attrs);
    delete primaryAttrs.id;
    delete primaryAttrs[k.class];
    return [attrs.ink && !attrs.disabled ? h(Ripple, _extends({}, attrs.ripple, requiresKeys ? { key: "ripple" } : null)) : null, primaryContent(h, k, requiresKeys, primaryAttrs, attrs.children || vnode.children), attrs.secondary ? secondaryContent(h, k, requiresKeys, Icon, attrs.secondary) : null];
  };

  var listTile = /*#__PURE__*/Object.freeze({
    getElement: getElement,
    createProps: createProps,
    createContent: createContent
  });

  var rgba = function rgba(colorStr) {
    var opacity = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 1;
    return "rgba(" + colorStr + ", " + opacity + ")";
  };

  // SPECS
  //
  // heights:
  // single line: 48
  // single line, dense: 40
  // single line, with icon: 48
  // single line, with icon, dense: 40
  // single line, with avatar: 56
  // single line, with avatar, dense: 48
  // two-line: 72
  // two-line, dense: 60
  // three-line: 88
  // three-line, dense: 76

  var single_height = 48;
  var padding = 8;
  var single_with_icon_height = 56;

  var vars = {
    compact_front_item_width: 64,
    compact_padding: 9,
    compact_side_padding: 1 * polytheneTheme.vars.grid_unit_component,
    font_size_list_header: 14,
    font_size_navigation_title: 14,
    font_size_small: 12,
    font_size_subtitle: 14,
    font_size_title: 16,
    font_weight_list_header: polytheneTheme.vars.font_weight_medium,
    font_weight_navigation_title: polytheneTheme.vars.font_weight_medium,
    font_weight_subtitle: polytheneTheme.vars.font_weight_normal,
    font_weight_title: polytheneTheme.vars.font_weight_normal,
    front_item_width: 72,
    has_high_subtitle_padding: 13,
    has_subtitle_padding: 15,
    high_subtitle_line_count: 2,
    line_height_subtitle: 20,
    padding: 13,
    side_padding: 2 * polytheneTheme.vars.grid_unit_component,
    single_height: single_height,
    single_line_height: single_height - 2 * padding - (2 * 5 + 1),
    single_with_icon_height: single_with_icon_height,
    single_with_icon_line_height: single_with_icon_height - 2 * padding - (2 * 5 + 1),
    subtitle_line_count: 1,
    title_line_count: 1,

    color_light_title: rgba(polytheneTheme.vars.color_light_foreground, polytheneTheme.vars.blend_light_text_primary),
    color_light_subtitle: rgba(polytheneTheme.vars.color_light_foreground, polytheneTheme.vars.blend_light_text_secondary),
    color_light_info: rgba(polytheneTheme.vars.color_light_foreground, polytheneTheme.vars.blend_light_text_tertiary),
    color_light_front: rgba(polytheneTheme.vars.color_light_foreground, polytheneTheme.vars.blend_light_text_secondary),
    color_light_text_disabled: rgba(polytheneTheme.vars.color_light_foreground, polytheneTheme.vars.blend_light_text_disabled),
    color_light_list_header: rgba(polytheneTheme.vars.color_light_foreground, polytheneTheme.vars.blend_light_text_tertiary),
    color_light_secondary: rgba(polytheneTheme.vars.color_light_foreground, polytheneTheme.vars.blend_light_text_secondary),
    color_light_hover: rgba(polytheneTheme.vars.color_light_foreground, polytheneTheme.vars.blend_light_text_primary),
    color_light_hover_front: rgba(polytheneTheme.vars.color_light_foreground, polytheneTheme.vars.blend_light_text_primary),
    color_light_hover_background: rgba(polytheneTheme.vars.color_light_foreground, polytheneTheme.vars.blend_light_background_hover),
    color_light_focus_background: rgba(polytheneTheme.vars.color_light_foreground, polytheneTheme.vars.blend_light_background_hover),
    color_light_selected_background: rgba(polytheneTheme.vars.color_light_foreground, polytheneTheme.vars.blend_light_background_hover),
    color_light_highlight_background: rgba(polytheneTheme.vars.color_light_foreground, polytheneTheme.vars.blend_light_background_hover),
    // background color may be set in theme; disabled by default
    // color_light_background:          "inherit",

    color_dark_title: rgba(polytheneTheme.vars.color_dark_foreground, polytheneTheme.vars.blend_dark_text_primary),
    color_dark_subtitle: rgba(polytheneTheme.vars.color_dark_foreground, polytheneTheme.vars.blend_dark_text_secondary),
    color_dark_info: rgba(polytheneTheme.vars.color_dark_foreground, polytheneTheme.vars.blend_dark_text_tertiary),
    color_dark_front: rgba(polytheneTheme.vars.color_dark_foreground, polytheneTheme.vars.blend_dark_text_secondary),
    color_dark_text_disabled: rgba(polytheneTheme.vars.color_dark_foreground, polytheneTheme.vars.blend_dark_text_disabled),
    color_dark_list_header: rgba(polytheneTheme.vars.color_dark_foreground, polytheneTheme.vars.blend_dark_text_tertiary),
    color_dark_secondary: rgba(polytheneTheme.vars.color_dark_foreground, polytheneTheme.vars.blend_dark_text_secondary),
    color_dark_hover: rgba(polytheneTheme.vars.color_dark_foreground, polytheneTheme.vars.blend_dark_text_primary),
    color_dark_hover_front: rgba(polytheneTheme.vars.color_dark_foreground, polytheneTheme.vars.blend_dark_text_primary),
    color_dark_hover_background: rgba(polytheneTheme.vars.color_dark_foreground, polytheneTheme.vars.blend_dark_background_hover),
    color_dark_selected_background: rgba(polytheneTheme.vars.color_dark_foreground, polytheneTheme.vars.blend_dark_background_hover),
    color_dark_highlight_background: rgba(polytheneTheme.vars.color_dark_foreground, polytheneTheme.vars.blend_dark_background_hover)
    // background color may be set in theme; disabled by default
    // color_dark_background:           "inherit",
  };

  exports.coreListTile = listTile;
  exports.vars = vars;

  Object.defineProperty(exports, '__esModule', { value: true });

})));
//# sourceMappingURL=polythene-core-list-tile.js.map
