(function (global, factory) {
  typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('polythene-theme'), require('polythene-core-base-spinner'), require('polythene-core'), require('polythene-utilities')) :
  typeof define === 'function' && define.amd ? define(['exports', 'polythene-theme', 'polythene-core-base-spinner', 'polythene-core', 'polythene-utilities'], factory) :
  (factory((global.polythene = {}),global['polythene-theme'],global['polythene-core-base-spinner'],global['polythene-core'],global['polythene-utilities']));
}(this, (function (exports,polytheneTheme,polytheneCoreBaseSpinner,polytheneCore,polytheneUtilities) { 'use strict';

  var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

  var rgba = function rgba(colorStr) {
    var opacity = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 1;
    return "rgba(" + colorStr + ", " + opacity + ")";
  };

  var themeVars = _extends({}, polytheneCoreBaseSpinner.vars, {
    border_width_small: polytheneCoreBaseSpinner.vars.size_small / polytheneCoreBaseSpinner.vars.size_regular * 3,
    border_width_regular: 3,
    border_width_medium: polytheneCoreBaseSpinner.vars.size_medium / polytheneCoreBaseSpinner.vars.size_regular * 3,
    border_width_large: polytheneCoreBaseSpinner.vars.size_large / polytheneCoreBaseSpinner.vars.size_regular * 3,
    border_width_fab: polytheneCoreBaseSpinner.vars.size_fab / polytheneCoreBaseSpinner.vars.size_regular * 3,
    animation_duration: "1.5s",

    color_light: rgba(polytheneTheme.vars.color_primary),
    color_dark: rgba(polytheneTheme.vars.color_primary)
  });

  var classes = {
    component: "pe-md-progress-spinner",

    // elements
    animation: "pe-md-progress-spinner__animation",
    circle: "pe-md-progress-spinner__circle",
    circleRight: "pe-md-progress-spinner__circle-right",
    circleLeft: "pe-md-progress-spinner__circle-left"
  };

  var _extends$1 = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

  var DEFAULT_UPDATE_DURATION = .8;

  var sizeFromName = function sizeFromName() {
    var size = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : "regular";
    return themeVars["size_" + size];
  };

  var percentageValue = function percentageValue(min, max) {
    var percentage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 0;
    return min + (max - min) * percentage;
  };

  var rotateCircle = function rotateCircle(el, min, max, percentage) {
    var style = el.style;
    style["transform"] = style["-webkit-transform"] = style["-moz-transform"] = style["-ms-transform"] = style["-o-transform"] = "rotate(" + percentageValue(min, max, percentage) + "deg)";
  };

  var animate = function animate(stateEl, size, percentage) {
    var animationEl = stateEl.querySelector("." + classes.animation);
    var animationElStyle = animationEl.style;
    if (percentage < 0.5) {
      animationElStyle.clip = "rect(0px, " + size + "px, " + size + "px, " + size / 2 + "px)";
    } else {
      animationElStyle.clip = "rect(auto, auto, auto, auto)";
    }
    var leftCircle = stateEl.querySelector("." + classes.circleLeft);
    var rightCircle = stateEl.querySelector("." + classes.circleRight);
    leftCircle.style.clip = rightCircle.style.clip = "rect(0px, " + size / 2 + "px, " + size + "px, " + "0px)";
    rotateCircle(rightCircle, 0, 180, Math.min(1, percentage * 2));
    rotateCircle(leftCircle, 0, 360, percentage);
  };

  var handlePercentage = function handlePercentage(percentage, state, size, attrs) {
    if (!state.dom()) {
      return;
    }
    if (state.animating()) {
      return;
    }
    var previousPercentage = state.percentage();
    if (attrs.animated && previousPercentage !== percentage) {
      var animationDuration = (attrs.updateDuration || DEFAULT_UPDATE_DURATION) * 1000;
      var el = state.dom();
      var start = null;
      var step = function step(timestamp) {
        if (!start) start = timestamp;
        var progress = timestamp - start;
        var stepPercentage = 1.0 / animationDuration * progress;
        var newPercentage = previousPercentage + stepPercentage * (percentage - previousPercentage);
        animate(el, size, polytheneUtilities.easing.easeInOutQuad(newPercentage));
        if (start && progress < animationDuration) {
          window.requestAnimationFrame(step);
        } else {
          start = null;
          state.percentage(percentage);
          state.animating(false);
        }
      };
      state.animating(true);
      window.requestAnimationFrame(step);
    } else {
      animate(state.dom(), size, percentage);
      state.percentage(percentage);
    }
  };

  var notifyState = function notifyState(state, attrs, size) {
    if (attrs.percentage !== undefined) {
      var percentage = polytheneCore.unpackAttrs(attrs.percentage);
      handlePercentage(percentage, state, size, attrs);
    }
  };

  var getSize = function getSize(attrs) {
    var rawSize = sizeFromName(attrs.size);

    var _themeVars$raisedSize = themeVars.raisedSize(rawSize),
        padding = _themeVars$raisedSize.padding,
        paddedSize = _themeVars$raisedSize.paddedSize;

    return attrs.raised ? paddedSize - 2 * padding : rawSize;
  };

  var getInitialState = function getInitialState(vnode, createStream) {
    var percentage = createStream(0);
    var dom = createStream(null);
    var animating = createStream(false);
    return {
      dom: dom,
      percentage: percentage,
      animating: animating
    };
  };

  var onMount = function onMount(vnode) {
    if (!vnode.dom) {
      return;
    }
    var state = vnode.state;
    var attrs = vnode.attrs;
    state.dom(vnode.dom);
    var size = getSize(attrs);
    notifyState(state, attrs, size);
  };

  var createProps = function createProps(vnode, _ref) {
    var h = _ref.renderer;

    var state = vnode.state;
    var attrs = vnode.attrs;
    var size = getSize(attrs);
    notifyState(state, attrs, size);

    var content = h("div", {
      key: "content",
      className: classes.animation,
      style: {
        width: size + "px",
        height: size + "px"
      }
    }, [h("div", {
      key: "left",
      className: [classes.circle, classes.circleLeft].join(" ")
    }), h("div", {
      key: "right",
      className: [classes.circle, classes.circleRight].join(" ")
    })]);

    return _extends$1({}, attrs, {
      className: [classes.component, attrs.className].join(" "),
      content: content
    });
  };

  var spinner = /*#__PURE__*/Object.freeze({
    getInitialState: getInitialState,
    onMount: onMount,
    createProps: createProps
  });

  exports.coreMaterialDesignProgressSpinner = spinner;
  exports.vars = themeVars;

  Object.defineProperty(exports, '__esModule', { value: true });

})));
//# sourceMappingURL=polythene-core-material-design-progress-spinner.js.map
