(function (global, factory) {
  typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('polythene-core'), require('polythene-theme')) :
  typeof define === 'function' && define.amd ? define(['exports', 'polythene-core', 'polythene-theme'], factory) :
  (factory((global.polythene = {}),global['polythene-core'],global['polythene-theme']));
}(this, (function (exports,polytheneCore,polytheneTheme) { 'use strict';

  var classes = {
    component: "pe-search",

    // elements
    content: "pe-search__content",

    // states
    searchFullWidth: "pe-search--full-width",
    searchInset: "pe-search--inset"
  };

  var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

  var getElement = function getElement(vnode) {
    return vnode.attrs.element || "div";
  };

  var getNameOfState = function getNameOfState(state) {
    return state.focus && state.dirty ? "focus_dirty" : state.focus ? "focus" : state.dirty ? "dirty" : "none";
  };

  var getInitialState = function getInitialState(vnode, createStream) {
    var searchState = createStream({});
    return {
      searchState: searchState
    };
  };

  var createProps = function createProps(vnode, _ref) {
    var k = _ref.keys;

    var attrs = vnode.attrs;
    return _extends({}, polytheneCore.filterSupportedAttributes(attrs), {
      className: [classes.component, attrs.fullWidth ? classes.searchFullWidth : classes.searchInset, attrs.tone === "dark" ? "pe-dark-tone" : null, attrs.tone === "light" ? "pe-light-tone" : null, attrs.className || attrs[k.class]].join(" ")
    }, attrs.events);
  };

  var createContent = function createContent(vnode, _ref2) {
    var h = _ref2.renderer,
        TextField = _ref2.TextField;

    var state = vnode.state;
    var attrs = vnode.attrs;
    var searchState = getNameOfState(state.searchState());
    var buttons = (attrs.buttons || {})[searchState] || {};
    var textfieldAttrs = attrs.textfield || {};
    return h("div", { className: classes.content }, [buttons.before, h(TextField, _extends({}, textfieldAttrs, {
      key: "input",
      onChange: function onChange(newState) {
        state.searchState(newState);
        if (textfieldAttrs.onChange) {
          textfieldAttrs.onChange(newState);
        }
      }
    })), buttons.after]);
  };

  var search = /*#__PURE__*/Object.freeze({
    getElement: getElement,
    getInitialState: getInitialState,
    createProps: createProps,
    createContent: createContent
  });

  var rgba = function rgba(colorStr) {
    var opacity = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 1;
    return "rgba(" + colorStr + ", " + opacity + ")";
  };

  var insetSideMargin = 8;
  var line_height_input = 20;
  var font_size_input = 20;
  var inset_height = 48;
  var inset_input_indent = 16;
  var inset_input_right_padding = 0;
  var inset_side_padding = 0;
  var inset_border_radius = polytheneTheme.vars.unit_block_border_radius;
  var full_width_side_margin = 0;
  var full_width_height = 56;
  var full_width_side_padding = insetSideMargin;
  var full_width_input_right_padding = 0;
  var full_width_border_radius = 0;

  var vars = {
    font_size_input: font_size_input,
    line_height_input: line_height_input,

    inset_height: inset_height,
    inset_input_indent: inset_input_indent,
    inset_side_padding: inset_side_padding,
    inset_input_right_padding: inset_input_right_padding,
    inset_border_radius: inset_border_radius,

    full_width_height: full_width_height,
    full_width_side_margin: full_width_side_margin,
    full_width_side_padding: full_width_side_padding,
    full_width_input_right_padding: full_width_input_right_padding,
    full_width_border_radius: full_width_border_radius,

    color_light_label_text: rgba(polytheneTheme.vars.color_light_foreground, polytheneTheme.vars.blend_light_text_disabled),
    color_light_input_text: rgba(polytheneTheme.vars.color_light_foreground, polytheneTheme.vars.blend_light_text_primary),
    color_light_background: rgba(polytheneTheme.vars.color_light_background),

    color_dark_label_text: rgba(polytheneTheme.vars.color_dark_foreground, polytheneTheme.vars.blend_dark_text_disabled),
    color_dark_input_text: rgba(polytheneTheme.vars.color_dark_foreground, polytheneTheme.vars.blend_dark_text_primary),
    color_dark_background: rgba(polytheneTheme.vars.color_dark_background)
  };

  exports.coreSearch = search;
  exports.vars = vars;

  Object.defineProperty(exports, '__esModule', { value: true });

})));
//# sourceMappingURL=polythene-core-search.js.map
