(function (global, factory) {
  typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('polythene-core-css'), require('polythene-core-list')) :
  typeof define === 'function' && define.amd ? define(['exports', 'polythene-core-css', 'polythene-core-list'], factory) :
  (factory((global.polythene = {}),global['polythene-core-css'],global['polythene-core-list']));
}(this, (function (exports,polytheneCoreCss,polytheneCoreList) { 'use strict';

  var listTileClasses = {
    component: "pe-list-tile",

    // elements
    content: "pe-list-tile__content",
    highSubtitle: "pe-list-tile__high-subtitle",
    primary: "pe-list-tile__primary",
    secondary: "pe-list-tile__secondary",
    subtitle: "pe-list-tile__subtitle",
    title: "pe-list-tile__title",
    contentFront: "pe-list-tile__content-front",

    // states
    compact: "pe-list-tile--compact",
    compactFront: "pe-list-tile--compact-front",
    disabled: "pe-list-tile--disabled",
    hasFront: "pe-list-tile--front",
    hasHighSubtitle: "pe-list-tile--high-subtitle",
    hasSubtitle: "pe-list-tile--subtitle",
    header: "pe-list-tile--header",
    hoverable: "pe-list-tile--hoverable",
    selectable: "pe-list-tile--selectable",
    selected: "pe-list-tile--selected",
    highlight: "pe-list-tile--highlight",
    sticky: "pe-list-tile--sticky",
    navigation: "pe-list-tile--navigation"
  };

  var classes = {
    component: "pe-list",

    // states
    border: "pe-list--border",
    compact: "pe-list--compact",
    hasHeader: "pe-list--header",
    indentedBorder: "pe-list--indented-border",
    padding: "pe-list--padding",
    paddingTop: "pe-list--padding-top",
    paddingBottom: "pe-list--padding-bottom",

    // lookup
    header: listTileClasses.header
  };

  function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

  var borderStyle = function borderStyle(componentVars) {
    return {
      borderStyle: "none none solid none",
      borderWidth: componentVars.border_width_bordered + "px"
    };
  };

  var layout = (function (selector, componentVars) {
    return [_defineProperty({}, selector, {

      ".pe-list--padding": {
        padding: componentVars.padding + "px 0"
      },
      ".pe-list--padding-top": {
        paddingTop: componentVars.padding + "px"
      },
      ".pe-list--padding-bottom": {
        paddingBottom: componentVars.padding + "px"
      },

      ".pe-list--header": {
        paddingTop: 0
      },

      ".pe-list--compact": {
        padding: componentVars.padding_compact + "px 0"
      },

      "& + &": {
        borderStyle: "solid none none none",
        borderWidth: componentVars.border_width_stacked + "px"
      },

      ".pe-list--border": {
        " .pe-list-tile": {
          ":not(.pe-list-tile--header):not(:last-child)": {
            "&": borderStyle(componentVars)
          }
        }
      },

      ".pe-list--indented-border": {
        borderTop: "none",

        " .pe-list-tile": {
          ":not(.pe-list-tile--header):not(:last-child)": {
            " .pe-list-tile__content:not(.pe-list-tile__content-front)": borderStyle(componentVars)
          }
        }
      }
    })];
  });

  function _defineProperty$1(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

  var style = function style(scopes, selector, componentVars, tint) {
    var _scopes$map$join;

    return [_defineProperty$1({}, scopes.map(function (s) {
      return s + selector;
    }).join(","), (_scopes$map$join = {
      backgroundColor: componentVars["color_" + tint + "_background"]

    }, _defineProperty$1(_scopes$map$join, "& + .pe-list", {
      borderTopColor: componentVars["color_" + tint + "_border"]
    }), _defineProperty$1(_scopes$map$join, ".pe-list--border", {
      " .pe-list-tile": {
        ":not(:last-child)": {
          borderColor: componentVars["color_" + tint + "_border"]
        }
      }
    }), _defineProperty$1(_scopes$map$join, ".pe-list--indented-border", {
      " .pe-list-tile": {
        " .pe-list-tile__content:not(.pe-list-tile__content-front)": {
          borderColor: componentVars["color_" + tint + "_border"]
        }
      }
    }), _scopes$map$join))];
  };

  var color = (function (selector, componentVars) {
    return [style([".pe-dark-tone", ".pe-dark-tone "], selector, componentVars, "dark"), // has/inside dark tone
    style(["", ".pe-light-tone", ".pe-light-tone "], selector, componentVars, "light")];
  });

  var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

  var fns = [layout, color];
  var selector = "." + classes.component;

  var addStyle = function addStyle(customSelector, customVars) {
    return polytheneCoreCss.styler.generateStyles([customSelector, selector], _extends({}, polytheneCoreList.vars, customVars), fns);
  };

  var getStyle = function getStyle(customSelector, customVars) {
    return customSelector ? polytheneCoreCss.styler.createStyleSheets([customSelector, selector], _extends({}, polytheneCoreList.vars, customVars), fns) : polytheneCoreCss.styler.createStyleSheets([selector], polytheneCoreList.vars, fns);
  };

  polytheneCoreCss.styler.generateStyles([selector], polytheneCoreList.vars, fns);

  exports.addStyle = addStyle;
  exports.getStyle = getStyle;

  Object.defineProperty(exports, '__esModule', { value: true });

})));
//# sourceMappingURL=polythene-css-list.js.map
